[Esbox-commits] r1554 - in branches/work_Ed/org.maemo.esbox.scratchbox.sb1: . src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin

eswartz at garage.maemo.org eswartz at garage.maemo.org
Thu May 7 20:02:34 EEST 2009


Author: eswartz
Date: 2009-05-07 20:02:32 +0300 (Thu, 07 May 2009)
New Revision: 1554

Modified:
   branches/work_Ed/org.maemo.esbox.scratchbox.sb1/plugin.xml
   branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/DiabloInstallerScriptWorkPage.java
   branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/NokiaBinariesInstallerData.java
   branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/SDKTargetSelectionPage.java
Log:
Bug 4057 -- binaries installer is not SB1 specific

(later: move to scratchbox.ui)

Modified: branches/work_Ed/org.maemo.esbox.scratchbox.sb1/plugin.xml
===================================================================
--- branches/work_Ed/org.maemo.esbox.scratchbox.sb1/plugin.xml	2009-05-07 14:53:45 UTC (rev 1553)
+++ branches/work_Ed/org.maemo.esbox.scratchbox.sb1/plugin.xml	2009-05-07 17:02:32 UTC (rev 1554)
@@ -93,9 +93,9 @@
             hasPages="true"
             icon="icons/full/obj16/build_target_icon.png"
             id="org.maemo.esbox.scratchbox.sb1.nokia_binaries_target_installer"
-            name="Scratchbox 1 Nokia-closed binaries">
+            name="Nokia-closed binaries">
             <description>
-               Install the Nokia-closed binaries for a given Maemo SDK into Scratchbox 1. 
+               Install the Nokia-closed binaries for a given Maemo SDK into Scratchbox. 
             </description>
       </wizard>
    </extension>

Modified: branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/DiabloInstallerScriptWorkPage.java
===================================================================
--- branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/DiabloInstallerScriptWorkPage.java	2009-05-07 14:53:45 UTC (rev 1553)
+++ branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/DiabloInstallerScriptWorkPage.java	2009-05-07 17:02:32 UTC (rev 1554)
@@ -27,7 +27,7 @@
 import org.eclipse.swt.widgets.Link;
 import org.maemo.esbox.internal.scratchbox.sb1.Activator;
 import org.maemo.esbox.internal.scratchbox.sb1.ui.process.ValidateNokiaBinariesInstallation;
-import org.maemo.esbox.scratchbox.sb1.sdk.IScratchbox1SDK;
+import org.maemo.esbox.scratchbox.core.sdk.IScratchboxSDK;
 import org.maemo.mica.common.core.Policy;
 import org.maemo.mica.common.core.machine.IBuildMachine;
 import org.maemo.mica.common.core.sdk.ISDKTarget;
@@ -189,8 +189,8 @@
 
 			final List<ISDKTarget> targets  = (List<ISDKTarget>) getWizard()
 					.getParameter("targets_selection");
-			final IScratchbox1SDK sdk  = (IScratchbox1SDK) getWizard().getParameter("sdk_selection");
-			installerData.setScratchbox1SDK(sdk);
+			final IScratchboxSDK sdk  = (IScratchboxSDK) getWizard().getParameter("sdk_selection");
+			installerData.setScratchboxSDK(sdk);
 			
 			final IBuildMachine buildMachine = getWizard().getBuildMachine();
 			

Modified: branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/NokiaBinariesInstallerData.java
===================================================================
--- branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/SDKTargetSelectionPage.java	2009-05-07 14:53:45 UTC (rev 1553)
+++ branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/SDKTargetSelectionPage.java	2009-05-07 17:02:32 UTC (rev 1554)
@@ -33,6 +33,7 @@
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Label;
 import org.maemo.esbox.internal.scratchbox.sb1.Activator;
+import org.maemo.esbox.scratchbox.core.sdk.IScratchboxSDK;
 import org.maemo.mica.common.core.sdk.ISDK;
 import org.maemo.mica.common.core.sdk.ISDKTarget;
 import org.maemo.mica.common.project.core.IBuildTargetFilter;
@@ -52,16 +53,11 @@
 	public static final String FREMANTLE = "FREMANTLE";
 
 	public static final String[] SDK_NAMES = new String[] { DIABLO, FREMANTLE };
-	/**
-	 * 
-	 */
-	public static final String SCRATCHBOX_1 = "scratchbox 1";
-
+	
 	private CheckboxTreeViewer targetTree;
 	private Combo fmaemoSDKCombo;
 	private String label;
-	private final MyBuildTargetFilter targetFilter = new MyBuildTargetFilter(
-			SCRATCHBOX_1, "");
+	private final MyBuildTargetFilter targetFilter = new MyBuildTargetFilter("");
 	private final WizardPage _page = this;
 	private ISDKTarget[] defaultTargets;
 
@@ -274,16 +270,14 @@
 	}
 
 	class MyBuildTargetFilter implements IBuildTargetFilter {
-		String scratchbox;
-		String sdkname;
 
-		public MyBuildTargetFilter(String scratchbox, String sdkname) {
-			this.scratchbox = scratchbox;
+		private String sdkname;
+		public MyBuildTargetFilter(String sdkname) {
 			this.sdkname = sdkname;
 		}
 
 		public boolean accept(ISDK sdk) {
-			if (sdk.getName().equalsIgnoreCase(scratchbox))
+			if (sdk instanceof IScratchboxSDK)
 				return true;
 			return false;
 		}



More information about the Esbox-commits mailing list
--- branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/NokiaBinariesInstallerData.java	2009-05-07 14:53:45 UTC (rev 1553)
+++ branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/NokiaBinariesInstallerData.java	2009-05-07 17:02:32 UTC (rev 1554)
@@ -19,19 +19,20 @@
 import java.util.Set;
 
 import org.eclipse.core.runtime.IPath;
-import org.maemo.esbox.scratchbox.sb1.sdk.IScratchbox1SDK;
+import org.maemo.esbox.scratchbox.core.sdk.IScratchboxSDK;
 
 
 
 /**
  * @author Fabrício S Epaminondas (UFCG) 
  *
+ * TODO: move all this stuff to the scratchbox.ui plugin
  */
 public class NokiaBinariesInstallerData {
 
 	private URL installerURL;
 	private Set<String> packages;
-	private IScratchbox1SDK scratchbox1SDK;
+	private IScratchboxSDK sdk;
 
 
 
@@ -120,25 +121,25 @@
 	
 	
 	/**
-	 * @return the scratchbox1SDK
+	 * @return the scratchboxSDK
 	 */
-	public IScratchbox1SDK getScratchbox1SDK() {
-		return scratchbox1SDK;
+	public IScratchboxSDK getScratchboxSDK() {
+		return sdk;
 	}
 
 
 	/**
 	 * @param scratchbox1SDK the scratchbox1SDK to set
 	 */
-	public void setScratchbox1SDK(IScratchbox1SDK scratchbox1SDK) {
-		this.scratchbox1SDK = scratchbox1SDK;
+	public void setScratchboxSDK(IScratchboxSDK scratchboxSDK) {
+		this.sdk = scratchboxSDK;
 	}
 
 	/**
 	 * @return the scratchboxLocation
 	 */
 	public String getScratchboxLocation() {
-		return scratchbox1SDK.getInstallRoot().toPortableString();
+		return sdk.getInstallRoot().toPortableString();
 	}
 
 }
@@ -120,25 +121,25 @@
 
 	/**
-	 * @param scratchbox1SDK the scratchbox1SDK to set
+	 * @param scratchboxSDK the scratchboxSDK to set
 	 */

Modified: branches/work_Ed/org.maemo.esbox.scratchbox.sb1/src/org/maemo/esbox/internal/scratchbox/sb1/ui/wizard/nokiabin/SDKTargetSelectionPage.java
===================================================================